# Getting Started with pydmoo

An introductory tutorial!

---

## Installation

To install pydmoo, run the following command from the command line:

### [uv](https://docs.astral.sh/uv/)

```shell
uv add pydmoo
```

### [poetry](https://python-poetry.org/)

```shell
poetry add pydmoo
```

### [pip](https://pip.pypa.io/en/stable/)

```shell
pip install pydmoo
```

## Getting help

For complete documentation of all pydmoo features, see the [User Guide]. And for help, please use the [GitHub issues].

[User Guide]: user-guide/index.md
[GitHub issues]: https://github.com/dynoptimization/pydmoo/issues
